@@ -8,7 +8,7 @@
 
 
 from dataclasses import dataclass
-from typing import Type, Any
+from typing import Type, Any, Optional
 import json
 
 from http_tools.http_server_connector import HttpServerConnector
@@ -34,31 +34,38 @@ class DetectorHttpConnector:
         self._connector = HttpServerConnector(config, context)
         self.detector_settings_type = detector_settings_type
 
-    async def get_settings(self, stream_urls: list[str], token: str) -> list[T]:
-        payload = {
-            "token": token,
-            "stream_urls": stream_urls
-        }
+    async def get_settings(self, stream_urls: list[str], token: Optional[str] = None) -> list[T]:
+        payload = {"stream_urls": stream_urls}
+
+        if token is not None:
+            payload.update({"token": token})
+
         answer = await self._connector.post_json("/settings/get",
                                                  payload=payload,
                                                  headers=self._construct_headers())
 
         return [dict_to_dataclass(settings, self.detector_settings_type) for settings in answer["result"]]
 
-    async def set_settings(self, detector_settings: T, token: str) -> T:
-        payload = {"token": token}
+    async def set_settings(self, detector_settings: T, token: Optional[str] = None) -> T:
+        payload = {"token": token} if token is not None else {}
+
         payload.update(json.loads(custom_dumps(detector_settings)))
+
         answer = await self._connector.post_json("/settings/set",
                                                  payload=payload,
                                                  headers=self._construct_headers())
+
         return dict_to_dataclass(answer["result"], self.detector_settings_type)
 
-    async def autotune_settings(self, detection: T, token: str) -> T:
-        payload = {"token": token}
+    async def autotune_settings(self, detection: T, token: Optional[str] = None) -> T:
+        payload = {"token": token} if token is not None else {}
+
         payload.update({"detection": json.loads(custom_dumps(detection))})
+
         answer = await self._connector.post_json("/settings/autotune",
                                                  payload=payload,
                                                  headers=self._construct_headers())
+
         return dict_to_dataclass(answer["result"], self.detector_settings_type)
 
     def _construct_headers(self) -> dict[str, str]:
